@@ -6,6 +6,7 @@ from fief.crypto.access_token import generate_access_token
 from fief.crypto.id_token import generate_id_token
 from fief.crypto.token import generate_token
 from fief.dependencies.current_workspace import get_current_workspace
+from fief.dependencies.logger import AuditLogger, get_audit_logger
 from fief.dependencies.permission import (
     UserPermissionsGetter,
     get_user_permissions_getter,
@@ -17,7 +18,7 @@ from fief.dependencies.token import (
     validate_grant_request,
 )
 from fief.dependencies.workspace_repositories import get_refresh_token_repository
-from fief.models import RefreshToken, Tenant, User, Workspace
+from fief.models import AuditLogMessage, RefreshToken, Tenant, User, Workspace
 from fief.repositories import RefreshTokenRepository
 from fief.schemas.auth import TokenResponse
 from fief.settings import settings
@@ -36,6 +37,7 @@ async def token(
     ),
     workspace: Workspace = Depends(get_current_workspace),
     tenant: Tenant = Depends(get_current_tenant),
+    audit_logger: AuditLogger = Depends(get_audit_logger),
 ):
     scope = grant_request["scope"]
     authenticated_at = grant_request["authenticated_at"]
@@ -88,6 +90,15 @@ async def token(
         refresh_token = await refresh_token_repository.create(refresh_token)
         token_response.refresh_token = token
 
+    audit_logger(
+        AuditLogMessage.USER_TOKEN_GENERATED,
+        author_user_id=user.id,
+        subject_user_id=user.id,
+        grant_type=grant_request["grant_type"],
+        authenticated_at=authenticated_at.isoformat(),
+        scope=scope,
+    )
+
     response.headers["Cache-Control"] = "no-store"
     response.headers["Pragma"] = "no-cache"
     return token_response.dict(exclude_none=True)
